indicatortools.LilyPondComment
==============================

.. abjad-lineage:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment

.. autoclass:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.contents_string
      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.format_slot
      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__copy__
      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__eq__
      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__format__
      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__hash__
      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__ne__
      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__repr__
      ~abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.contents_string
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.format_slot
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__hash__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__repr__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondComment.LilyPondComment.__str__
   :noindex:
